@@ -144,7 +144,7 @@ class GatewayMappingKernelManager(AsyncMappingKernelManager):
             The purpose of this shutdown is to restart the kernel (True)
         """
         km = self.get_kernel(kernel_id)
-        await km.shutdown_kernel(now=now, restart=restart)
+        await ensure_async(km.shutdown_kernel(now=now, restart=restart))
         self.remove_kernel(kernel_id)
 
     async def restart_kernel(self, kernel_id, now=False, **kwargs):
@@ -156,7 +156,7 @@ class GatewayMappingKernelManager(AsyncMappingKernelManager):
             The id of the kernel to restart.
         """
         km = self.get_kernel(kernel_id)
-        await km.restart_kernel(now=now, **kwargs)
+        await ensure_async(km.restart_kernel(now=now, **kwargs))
 
     async def interrupt_kernel(self, kernel_id, **kwargs):
         """Interrupt a kernel by its kernel uuid.
@@ -167,14 +167,14 @@ class GatewayMappingKernelManager(AsyncMappingKernelManager):
             The id of the kernel to interrupt.
         """
         km = self.get_kernel(kernel_id)
-        await km.interrupt_kernel()
+        await ensure_async(km.interrupt_kernel())
 
     async def shutdown_all(self, now=False):
         """Shutdown all kernels."""
         kids = list(self._kernels)
         for kernel_id in kids:
             km = self.get_kernel(kernel_id)
-            await km.shutdown_kernel(now=now)
+            await ensure_async(km.shutdown_kernel(now=now))
             self.remove_kernel(kernel_id)
 
     async def cull_kernels(self):
@@ -218,13 +218,16 @@ class GatewayKernelSpecManager(KernelSpecManager):
             for resource_name in resources:
                 original_path = resources[resource_name]
                 split_eg_base_url = str.rsplit(original_path, sep="/kernelspecs/", maxsplit=1)
-                new_path = url_path_join(self.parent.base_url, "kernelspecs", split_eg_base_url[1])
-                kernel_specs["kernelspecs"][kernel_name]["resources"][resource_name] = new_path
-                if original_path != new_path:
-                    self.log.debug(
-                        f"Replaced original kernel resource path {original_path} with new "
-                        f"path {kernel_specs['kernelspecs'][kernel_name]['resources'][resource_name]}"
+                if len(split_eg_base_url) > 1:
+                    new_path = url_path_join(
+                        self.parent.base_url, "kernelspecs", split_eg_base_url[1]
                     )
+                    kernel_specs["kernelspecs"][kernel_name]["resources"][resource_name] = new_path
+                    if original_path != new_path:
+                        self.log.debug(
+                            f"Replaced original kernel resource path {original_path} with new "
+                            f"path {kernel_specs['kernelspecs'][kernel_name]['resources'][resource_name]}"
+                        )
         return kernel_specs
 
     def _get_kernelspecs_endpoint_url(self, kernel_name=None):
