@@ -121,7 +121,7 @@ class FileContentsManager(FileManagerMixin, ContentsManager):
 
         Parameters
         ----------
-        path : string
+        path : str
             The path to check. This is an API path (`/` separated,
             relative to root_dir).
 
@@ -139,7 +139,7 @@ class FileContentsManager(FileManagerMixin, ContentsManager):
 
         Parameters
         ----------
-        path : string
+        path : str
             The path to check. This is an API path (`/` separated,
             relative to root_dir).
 
@@ -163,7 +163,7 @@ class FileContentsManager(FileManagerMixin, ContentsManager):
 
         Parameters
         ----------
-        path : string
+        path : str
             The relative path to the file (with '/' as separator)
 
         Returns
@@ -182,7 +182,7 @@ class FileContentsManager(FileManagerMixin, ContentsManager):
 
         Parameters
         ----------
-        path : string
+        path : str
             The path to check. This is an API path (`/` separated,
             relative to root_dir).
 
@@ -202,7 +202,7 @@ class FileContentsManager(FileManagerMixin, ContentsManager):
 
         Parameters
         ----------
-        path : string
+        path : str
             The API path to the file (with '/' as separator)
 
         Returns
@@ -287,7 +287,7 @@ class FileContentsManager(FileManagerMixin, ContentsManager):
                 try:
                     os_path = os.path.join(os_dir, name)
                 except UnicodeDecodeError as e:
-                    self.log.warning("failed to decode filename '%s': %s", name, e)
+                    self.log.warning("failed to decode filename '%s': %r", name, e)
                     continue
 
                 try:
@@ -297,7 +297,7 @@ class FileContentsManager(FileManagerMixin, ContentsManager):
                     if e.errno == errno.ENOENT:
                         self.log.warning("%s doesn't exist", os_path)
                     elif e.errno != errno.EACCES:  # Don't provide clues about protected files
-                        self.log.warning("Error stat-ing %s: %s", os_path, e)
+                        self.log.warning("Error stat-ing %s: %r", os_path, e)
                     continue
 
                 if (
@@ -636,7 +636,7 @@ class AsyncFileContentsManager(FileContentsManager, AsyncFileManagerMixin, Async
                 try:
                     os_path = os.path.join(os_dir, name)
                 except UnicodeDecodeError as e:
-                    self.log.warning("failed to decode filename '%s': %s", name, e)
+                    self.log.warning("failed to decode filename '%s': %r", name, e)
                     continue
 
                 try:
@@ -646,7 +646,7 @@ class AsyncFileContentsManager(FileContentsManager, AsyncFileManagerMixin, Async
                     if e.errno == errno.ENOENT:
                         self.log.warning("%s doesn't exist", os_path)
                     elif e.errno != errno.EACCES:  # Don't provide clues about protected files
-                        self.log.warning("Error stat-ing %s: %s", os_path, e)
+                        self.log.warning("Error stat-ing %s: %r", os_path, e)
                     continue
 
                 if (
